/**
 * 
 * @param {Object} re_CompInfo_obj Reference to the Component Object containing all information to located all information to build row info array in the instruction object
 * @param {Object} ref_instruct_obj Reference to the instruction object to get component info and any settings
 * @param {String} buildtBody_class Name of the Table Builder tbody class that holds all the info need to create the component
 * @param {Array} info_col_def Array that defines the type of info in each of the builder columns
 * @returns True if was able to create the info table for the instruction object
 */
 function Build_Info_Array(re_CompInfo_obj,ref_instruct_obj,buildtBody_class,info_col_def){
    const ref_buildtbody_class = SearchChildrenFor([['tagName','TBODY'],['class',buildtBody_class]],re_CompInfo_obj.buiDIV_element);
	if (ref_buildtbody_class){
        Get_Component_Info(ref_buildtbody_class,info_col_def,re_CompInfo_obj,ref_instruct_obj);
        Find_Build_Settings_Array(re_CompInfo_obj.buiDIV_element,ref_instruct_obj);
	}
    if(ref_instruct_obj.getIA_Size() > 0){
        return true;
    }else{
        return false;
    }
}

/**
 * Parses the builder and creates an info array with all the information needed to build the component
 * @param {*} ref_tbo_element Reference to the table body element in the builder
 * @param {*} inf_col_def Defines type of information is found in each of the builder columns
 * @param {*} re_CompInfo_obj Reference to the Component Object containing all information to located all information to build row info array in the instruction object
 * @param {*} ref_instruct_obj Reference to the info array object
 */
 function Get_Component_Info(ref_tbo_element,inf_col_def,re_CompInfo_obj,ref_instruct_obj){
    const compsTREle = ref_tbo_element.children;
    let row;
    let compTRNum = 1;
    let compsInfoTDEle;
    const aID = Get_UNQ_RNDid();
    if(re_CompInfo_obj.activity_ID == null){
        re_CompInfo_obj.activity_ID = aID;
    }
    for (row=0; row < compsTREle.length; row++){ //for each tr found is a comp
        let row_array=new Array();
        if(compsTREle[row].tagName != null && compsTREle[row].tagName == "TR"){
            compsInfoTDEle = compsTREle[row].children;
            let col;
            let infoTDNum = 0; //array index starts at 0
            //need to check if first col in the inf_col_def is an ID, if then the first col is just the id
            let isAddedIDCol = false;
            if(inf_col_def[0]!='ID'){ //always add the first column index as an ID even if the col definition is not specified as an ID
                //add the first column as id
                isAddedIDCol = true;
            }
            for(col=0; col<compsInfoTDEle.length; col++){ //comp info found in these td columns
                const divContent = document.createElement("DIV");
                if (isAddedIDCol || (compsInfoTDEle[col].tagName != null && compsInfoTDEle[col].tagName == "TD")){
                    if (isAddedIDCol || inf_col_def[infoTDNum]=='TEXT' || inf_col_def[infoTDNum]=='ID'){//comp header or ID found in these columns
                        let compName;
                        if(isAddedIDCol){
                            compName = aID
                            let textNodeFound = document.createTextNode(compName);
                            divContent.append(textNodeFound);
                        }else{
                            Grab_Content(compsInfoTDEle[col],'TEXT',divContent);
                        }
                    }else if(inf_col_def[infoTDNum]=='MIXED'){ //comp content found in these columns
                        Grab_Content(compsInfoTDEle[col],'MIXED',divContent);
                    }
                    row_array.push(divContent);
                    if(isAddedIDCol){
                        isAddedIDCol = false;
                        col = -1;
                    }else{
                        infoTDNum++;
                    }
                }
            }
            compTRNum++;
            ref_instruct_obj.row_info_arrays.push(row_array);
        }
    }
}

function Set_Empty_toIndexVal_ColAt(instruct_obj,cols){
    if(instruct_obj.getIA_Size()){
        for(let i=0; i<instruct_obj.getIA_Size(); i++){
            //check the value at each cols number if empty then create text node with value of index
            for(let col of cols){
                colVal = instruct_obj.get_info_At_ColNUM(i,col);
                let isNeedofVal = false;
                if(colVal){
                    //check to see if the div is empty
                    const colValDiv = colVal.children;
                    if(colValDiv && colValDiv.length == 0){
                        //check to see if it's just textContent without any children
                        colDiv_val = colVal.textContent;
                        if(colDiv_val==null || colDiv_val == ""){
                            isNeedofVal = true;
                        }
                    }
                }
                if(isNeedofVal){
                    const divContent_col = document.createElement("DIV");
                    const textNode_val = document.createTextNode((i+1).toString());
                    divContent_col.append(textNode_val);
                    instruct_obj.set_info_At_ColNUM(i,col,divContent_col);
                }
            }
        }
    }
}

